@@ -100,7 +100,6 @@ vec_arith.pillar_num <- function(op, x, y, ...) {
 #' @export
 vec_arith.pillar_num.default <- function(op, x, y, ...) {
   "!!!!DEBUG vec_arith.pillar_num.default(`v(op)`)"
-  stopifnot(is.numeric(x), is.numeric(y))
   out <- vec_arith_base(op, vec_proxy(x), vec_proxy(y))
 
   if (inherits(x, "pillar_num")) {
@@ -113,7 +112,6 @@ vec_arith.pillar_num.default <- function(op, x, y, ...) {
 #' @export
 vec_arith.pillar_num.MISSING <- function(op, x, y, ...) {
   "!!!!DEBUG vec_arith.pillar_num.MISSING(`v(op)`)"
-  stopifnot(is.numeric(x))
   # FIXME
   out <- vec_arith_base(op, 0, vec_proxy(x))
 
@@ -126,14 +124,13 @@ vec_arith.numeric.pillar_num <- vec_arith.pillar_num.default
 
 
 #' @export
-vec_math.pillar_num <- function(op, x, ...) {
-  "!!!!DEBUG vec_math(`v(op)`)"
+vec_math.pillar_num <- function(.fn, .x, ...) {
+  "!!!!DEBUG vec_math(`v(.fn)`)"
 
-  stopifnot(is.numeric(x))
-  out <- vec_math_base(op, vec_proxy(x))
+  out <- vec_math_base(.fn, vec_proxy(.x))
 
   if (is.numeric(out)) {
-    out <- vec_restore(out, x)
+    out <- vec_restore(out, .x)
   }
 
   out
@@ -281,9 +278,13 @@ vec_cast.double.pillar_num <- function(x, to, ...) {
 }
 #' @export
 vec_cast.pillar_num.double <- function(x, to, ...) {
-  vec_restore(vec_proxy(x), to)
+  out <- num(x)
+  attr(out, "pillar") <- attr(to, "pillar")
+  out
 }
 #' @export
 vec_cast.pillar_num.integer <- function(x, to, ...) {
-  vec_restore(as.numeric(x), to)
+  out <- num(as.numeric(x))
+  attr(out, "pillar") <- attr(to, "pillar")
+  out
 }
