@@ -17,10 +17,7 @@ print_tbl <- function(x, width = NULL, ...,
                       n_extra = NULL,
                       n = NULL, max_extra_cols = NULL, max_footer_lines = NULL) {
   if (!is.null(n_extra)) {
-    deprecate_soft(
-      "1.6.2", "pillar::print(n_extra = )", "pillar::print(max_extra_cols = )",
-      user_env = caller_env(2)
-    )
+    deprecate_stop("1.6.2", "pillar::print(n_extra = )", "pillar::print(max_extra_cols = )")
     if (is.null(max_extra_cols)) {
       max_extra_cols <- n_extra
     }
@@ -50,10 +47,7 @@ format_tbl <- function(x, width = NULL, ...,
   check_dots_empty(action = signal)
 
   if (!is.null(n_extra)) {
-    deprecate_soft(
-      "1.6.2", "pillar::format(n_extra = )", "pillar::format(max_extra_cols = )",
-      user_env = caller_env(2)
-    )
+    deprecate_stop("1.6.2", "pillar::format(n_extra = )", "pillar::format(max_extra_cols = )")
     if (is.null(max_extra_cols)) {
       max_extra_cols <- n_extra
     }
